@@ -2,6 +2,7 @@
     Contains the general methods for manipulating directories.
 '''
 # import json
+import json
 import traceback
 import shutil
 import os
@@ -124,39 +125,36 @@ def get_files(search_path=False, **kwargs):
     if isinstance(extension_array, (str)):
         extension_array = [extension_array]
 
-    # if isinstance(ignore_array, list) is False:
-    #     ignore_array = [ignore_array]
-
-    # print(f"extension_array: {extension_array}")
-
+    # print(json.dumps(extension_array, indent=4))
     for path in search_path:
         # pylint: disable=unused-variable
         for root, folders, files in os.walk(path):
             for file in files:
                 file_data = f.get_data(os.path.join(root, file))
-                # ignore = False
-                # print(f"file_data['extension']: {file_data['extension']}")
-                if len(exclude) > 0:
-                    if array_in_string(exclude, file_data['file_path']) is True:
-                        continue
+                if file_data is not None:
+                    # ignore = False
+                    # print(f"file_data['extension']: {file_data['extension']}")
+                    if len(exclude) > 0:
+                        if array_in_string(exclude, file_data['file_path']) is True:
+                            continue
 
-                if len(include) > 0:
-                    if array_in_string(include, file_data['file_path']) is False:
-                        continue
+                    if len(include) > 0:
+                        if array_in_string(include, file_data['file_path']) is False:
+                            continue
 
-                if len(extension_array) > 0:
-                    if strUtils.format_extension(file_data['extension']) not in extension_array:
-                        # ignore = True
-                        continue
+                    if len(extension_array) > 0:
+                        file_ext = strUtils.format_extension(file_data['extension'])
+                        if file_ext not in extension_array:
+                            continue
 
-                # if len(ignore_array) > 0:
-                #     for ignore_string in ignore_array:
-                #         if ignore_string in file_data['file_path']:
-                #             ignore = True
+                    # if len(ignore_array) > 0:
+                    #     for ignore_string in ignore_array:
+                    #         if ignore_string in file_data['file_path']:
+                    #             ignore = True
 
-                # if ignore is False:
-                    # fd['file_hash'] = generateFileHash(fd['file_path'])
-                file_array.append(file_data)
+                    # if ignore is False:
+                        # fd['file_hash'] = generateFileHash(fd['file_path'])
+                    file_array.append(file_data)
 
             if recursive is False:
                 break
