@@ -24,6 +24,9 @@ import string_utils as strUtils
 from secure_delete import secure_delete
 from threading import Thread
 import colemen_string_utils as strUtils
+import logging
+
+logger = logging.getLogger(__name__)
 
 # pylint: disable=line-too-long
 DEST_PATH_SYNONYMS = ["dest", "dst", "dest path", "destination", "destination path", "dst path", "target", "target path"]
@@ -34,76 +37,6 @@ SRC_PATH_SYNONYMS = ["source", "src", "src path", "source path", "file path"]
 # // TODO:Get optional file access,create,modified formatting.
 
 
-def get_data(file_path, **kwargs):
-    '''
-        Get data associated to the file_path provided.
-
-        ----------
-        Arguments
-        -----------------
-        `file_path`=cwd {str}
-            The path to the file.
-
-        Keyword Arguments
-        -----------------
-
-            `exclude`=[] {list}
-                A list of keys to exclude from the returning dictionary.
-                This is primarily useful for limiting the time/size of the operation.
-
-        Return
-        ----------
-        `return` {str}
-            A dictionary containing the file's data.
-    '''
-    exclude = obj.get_kwarg(['exclude'], [], (list, str), **kwargs)
-
-    file_data = {}
-    file_data['file_name'] = os.path.basename(file_path)
-    # ext = os.path.splitext(file_data['file_name'])
-    file_data['extension'] = get_ext(file_path)
-    file_data['name_no_ext'] = get_name_no_ext(file_path)
-    file_data['file_path'] = file_path
-
-    if 'dir_path' not in exclude:
-        file_data['dir_path'] = os.path.dirname(file_path)
-    if 'access_time' not in exclude:
-        file_data['access_time'] = get_access_time(file_path)
-    if 'modified_time' not in exclude:
-        file_data['modified_time'] = get_modified_time(file_path)
-    if 'created_time' not in exclude:
-        file_data['created_time'] = get_create_time(file_path)
-    if 'size' not in exclude:
-        file_data['size'] = os.path.getsize(file_path)
-
-    return file_data
-
-
-def get_modified_time(file_path):
-    mod_time = os.path.getmtime(file_path)
-    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
-
-
-def get_access_time(file_path):
-    mod_time = os.path.getatime(file_path)
-    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
-
-
-def get_create_time(file_path):
-    mod_time = os.path.getctime(file_path)
-    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
-
-
-def get_ext(file_path):
-    file_name = os.path.basename(file_path)
-    ext = os.path.splitext(file_name)
-    return ext[1]
-
-
-def get_name_no_ext(file_path):
-    return os.path.basename(file_path).replace(get_ext(file_path), '')
-
-
 def decompress(file_obj, compression="gzip"):
     file_list = _gen_path_list(file_obj)
 
@@ -516,3 +449,212 @@ def _thread_file_action(file_list, **kwargs):
     for thread in threads:
         thread.join()
     return
+
+
+def get_data(file_path, **kwargs):
+    '''
+        Get data associated to the file_path provided.
+
+        ----------
+
+        Arguments
+        -----------------
+        `file_path`=cwd {str}
+            The path to the file.
+
+        Keyword Arguments
+        -----------------
+
+            `exclude`=[] {list}
+                A list of keys to exclude from the returning dictionary.
+                This is primarily useful for limiting the time/size of the operation.
+
+        Return
+        ----------
+        `return` {str}
+            A dictionary containing the file's data.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-13-2021 11:02:09
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: get_data
+    '''
+
+    file_path = strUtils.format.file_path(file_path)
+    exclude = obj.get_kwarg(['exclude'], [], (list, str), **kwargs)
+    if exists(file_path):
+        print(f"file exists: {file_path}")
+    try:
+        file_data = {}
+        file_data['file_name'] = os.path.basename(file_path)
+        # ext = os.path.splitext(file_data['file_name'])
+        file_data['extension'] = get_ext(file_path)
+        file_data['name_no_ext'] = get_name_no_ext(file_path)
+        file_data['file_path'] = file_path
+
+        if 'dir_path' not in exclude:
+            file_data['dir_path'] = os.path.dirname(file_path)
+        if 'access_time' not in exclude:
+            file_data['access_time'] = get_access_time(file_path)
+        if 'modified_time' not in exclude:
+            file_data['modified_time'] = get_modified_time(file_path)
+        if 'created_time' not in exclude:
+            file_data['created_time'] = get_create_time(file_path)
+        if 'size' not in exclude:
+            file_data['size'] = os.path.getsize(file_path)
+
+        return file_data
+    except FileNotFoundError as error:
+        logger.warning(f"Error: {error}")
+        logger.warning(f"Failed to find the file: {file_path}")
+        return None
+
+
+def get_modified_time(file_path):
+    '''
+        get the modified from the file
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_path` {string}
+            The file to get the modified time from.
+
+        Return {int}
+        ----------------------
+        The timestamp formatted and rounded.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-13-2021 10:45:32
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: get_modified_time
+    '''
+    mod_time = os.path.getmtime(file_path)
+    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
+
+
+def get_access_time(file_path):
+    '''
+        get the access from the file
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_path` {string}
+            The file to get the access time from.
+
+        Return {int}
+        ----------------------
+        The timestamp formatted and rounded.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-13-2021 10:45:32
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: get_modified_time
+    '''
+    mod_time = os.path.getatime(file_path)
+    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
+
+
+def get_create_time(file_path):
+    '''
+        get the create from the file
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_path` {string}
+            The file to get the create time from.
+
+        Return {int}
+        ----------------------
+        The timestamp formatted and rounded.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-13-2021 10:45:32
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: get_modified_time
+    '''
+    mod_time = os.path.getctime(file_path)
+    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
+
+
+def get_ext(file_path):
+    '''
+        Get the extension from the file path provided.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_path` {string}
+            The file path to be parsed.
+
+        Return {string|boolean}
+        ----------------------
+        The extension of the file, if it can be parsed, False otherwise.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-13-2021 10:40:21
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: get_ext
+    '''
+    file_name = os.path.basename(file_path)
+    file_extension = False
+    ext = os.path.splitext(file_name)
+    if len(ext) == 2:
+        file_extension = ext[1]
+    return file_extension
+
+
+def get_name_no_ext(file_path):
+    '''
+        Get the file name without an extension.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_path` {string}
+            The file path to be parsed.
+
+        Return {type}
+        ----------------------
+        The file name without the extension
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-13-2021 10:38:44
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: get_name_no_ext
+    '''
+    return os.path.basename(file_path).replace(get_ext(file_path), '')
+
+
+# file = r"C:\Users\Colemen\Desktop\DAZDOW~1\poses\STANDI~1\IM0008~1\Content\People\GENESI~2\Poses\AEONSO~1\STANDI~1\LIMBSL~1\SC-WE'~2.DUF"
+# file = r"C:\\Users\\Colemen\\Desktop\\DAZ DOWNLOADS\\poses\\Standing Conversation Poses for Genesis 8\\IM00083571-01_StandingConversationPosesforGenesis8\\Content\\People\\Genesis 8 Male\\Poses\\Aeon Soul\\Standing Conversation\\Limbs Legs\\SC-We're all in the same boat Legs-M Genesis 8 Male.duf"
+# clean = clean_path(file)
+# print(f"clean file path: {clean}")
+# print(exists(clean))
+# file = strUtils.format.file_path(file)
+# get_data(file)
